This court is a specialist court within the Chancery Division of the High Court. It is also one of the Business and Property Courts. It specialises in cases involving patents, registered designs and plant varieties. Typically it handles cases where damages sought are over £500,000. Cases less than £500,000 are typically handled by the Intellectual Property Enterprise Court.

This court began to regularly transfer judgments to The National Archives in 2022. The oldest judgment from this court included in Find Case Law is from {start_year}.

You can read more about [the Patents Court on the Judiciary website](https://www.judiciary.uk/courts-and-tribunals/business-and-property-courts/business-list-general-chancery/intellectual-property-list/patents-court/){target="\_blank"}.
